@@ -5,6 +5,7 @@
 import ctypes
 import queue
 import textwrap
+import warnings
 
 # 3rd party library imports
 import numpy as np
@@ -32,10 +33,7 @@ def version():
     return v.decode('utf-8')
 
 
-if OPENJP2 is not None:
-    _MAJOR, _MINOR, _PATCH = [int(x) for x in version().split('.')]
-else:
-    _MAJOR, _MINOR, _PATCH = 0, 0, 0
+_MAJOR, _MINOR, _PATCH = [int(x) for x in version().split('.')]
 
 ERROR_MSG_LST = queue.Queue()
 
@@ -972,13 +970,15 @@ def encoder_set_extra_options(codec, plt=False, tlm=False):
     OPENJP2.opj_encoder_set_extra_options.argtypes = ARGTYPES
     OPENJP2.opj_encoder_set_extra_options.restype = check_error
 
+    # Send the library a null terminated array of char instructions.  As of
+    # version 2.4.0, there is only a single instruction possible.  As of 2.5.0,
+    # there are two possible instructions.
     arr = (ctypes.c_char_p * 3)()
+    arr[0] = arr[1] = arr[2] = None
+
     arr[0] = 'PLT=YES'.encode('utf-8') if plt else 'PLT=NO'.encode('utf-8')
     if version() >= '2.5.0':
         arr[1] = 'TLM=YES'.encode('utf-8') if tlm else 'TLM=NO'.encode('utf-8')
-        arr[2] = None
-    else:
-        arr[1] = None
 
     OPENJP2.opj_encoder_set_extra_options(codec, arr)
 
@@ -1495,3 +1495,32 @@ def write_tile(codec, tile_index, data, *pargs):
 def set_error_message(msg):
     """The openjpeg error handler has recorded an error message."""
     ERROR_MSG_LST.put(msg)
+
+
+# Setup the default callback handlers.  See the callback functions subsection
+# in the ctypes section of the Python documentation for a solid explanation of
+# what's going on here.
+_CMPFUNC = ctypes.CFUNCTYPE(ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p)
+
+
+def _default_error_handler(msg, _):
+    """Default error handler callback for libopenjp2."""
+    msg = "OpenJPEG library error:  {0}".format(msg.decode('utf-8').rstrip())
+    set_error_message(msg)
+
+
+def _default_info_handler(msg, _):
+    """Default info handler callback."""
+    print("[INFO] {0}".format(msg.decode('utf-8').rstrip()))
+
+
+def _default_warning_handler(library_msg, _):
+    """Default warning handler callback."""
+    library_msg = library_msg.decode('utf-8').rstrip()
+    msg = "OpenJPEG library warning:  {0}".format(library_msg)
+    warnings.warn(msg, UserWarning)
+
+
+_ERROR_CALLBACK = _CMPFUNC(_default_error_handler)
+_INFO_CALLBACK = _CMPFUNC(_default_info_handler)
+_WARNING_CALLBACK = _CMPFUNC(_default_warning_handler)
