@@ -1,7 +1,6 @@
 """Test suite specifically targeting JP2 box layout.
 """
 # Standard library imports ...
-import doctest
 import importlib.resources as ir
 from io import BytesIO
 import os
@@ -21,11 +20,11 @@ import numpy as np
 
 # Local imports ...
 import glymur
-from glymur import Jp2k
+from glymur import Jp2k, Jp2kr
 from glymur.jp2box import (
     ColourSpecificationBox, ContiguousCodestreamBox, FileTypeBox,
     ImageHeaderBox, JP2HeaderBox, JPEG2000SignatureBox, BitsPerComponentBox,
-    PaletteBox, UnknownBox, InvalidJp2kError
+    PaletteBox, CaptureResolutionBox, UnknownBox, InvalidJp2kError
 )
 from glymur.core import COLOR, OPACITY, SRGB, GREYSCALE
 from glymur.core import RED, GREEN, BLUE, GREY, WHOLE_IMAGE
@@ -33,20 +32,6 @@ from . import fixtures
 from .fixtures import OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG
 
 
-def docTearDown(doctest_obj):  # pragma: no cover
-    glymur.set_option('parse.full_codestream', False)
-
-
-def load_tests(loader, tests, ignore):  # pragma: no cover
-    """Run doc tests as well."""
-    if os.name == "nt":
-        # Can't do it on windows, temporary file issue.
-        return tests
-    tests.addTests(doctest.DocTestSuite('glymur.jp2box',
-                                        tearDown=docTearDown))
-    return tests
-
-
 @unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
 class TestDataEntryURL(fixtures.TestCommon):
     """Test suite for DataEntryURL boxes."""
@@ -371,6 +356,16 @@ class TestChannelDefinition(fixtures.TestCommon):
 class TestFileTypeBox(fixtures.TestCommon):
     """Test suite for ftyp box issues."""
 
+    def test_jph(self):
+        """
+        SCENARIO:  JPH box
+
+        EXPECTED RESULT:  The brand is verified.
+        """
+        path = ir.files('tests.data').joinpath('oj-ht-byte.jph')
+        j = Jp2kr(path)
+        self.assertEqual(j.box[1].brand, 'jph ')
+
     def test_bad_brand_on_parse(self):
         """
         SCENARIO:  The JP2 file file type box does not contain a valid brand.
@@ -422,6 +417,17 @@ class TestResolutionBoxes(fixtures.TestCommon):
     """
     Test suite for resolution boxes
     """
+    def test_invalid_resolution(self):
+        """
+        Scenario:  the supplied resolution cannot be represented
+
+        Expected Result:  ValueError when trying to write
+        """
+        resc = CaptureResolutionBox(1e-200, 0.5)
+        with self.assertRaises(ValueError):
+            with tempfile.NamedTemporaryFile(mode='wb') as tf:
+                resc.write(tf)
+
     def test_repr(self):
         """
         Verify __repr__ method on resolution boxes.
@@ -556,7 +562,9 @@ class TestPaletteBox(fixtures.TestCommon):
 
     def test_signed_components(self):
         """
-        Palettes with signed components are not supported.
+        Scenario:  a palette box with signed components is read (not supported)
+
+        Expected Results InvalidJp2kError
         """
         b = BytesIO()
 
@@ -568,10 +576,9 @@ class TestPaletteBox(fixtures.TestCommon):
         nrows = 2
         b.write(struct.pack('>HB', nrows, ncols))
 
-        # bits per sample is 8, but signed
-        bps = (np.int8(7), np.int8(7), np.int8(7))
-        bps_signed = (x | 0x80 for x in bps)
-        b.write(struct.pack('BBB', *bps_signed))
+        # Force the leading bit to be 1, which signifies "signed"
+        bps = (np.int8(-1), np.int8(-1), np.int8(-1))
+        b.write(struct.pack('bbb', *bps))
 
         # Write the palette itself.
         #
@@ -602,7 +609,7 @@ class TestAppend(fixtures.TestCommon):
             # The sequence of box IDs should be the same as before, but with an
             # xml box at the end.
             box_ids = [box.box_id for box in jp2.box]
-            expected = ['jP  ', 'ftyp', 'jp2h', 'uuid', 'jp2c', 'xml ']
+            expected = ['jP  ', 'ftyp', 'jp2h', 'jp2c', 'xml ']
             self.assertEqual(box_ids, expected)
             self.assertEqual(
                 ET.tostring(jp2.box[-1].xml.getroot()),
@@ -654,7 +661,7 @@ class TestAppend(fixtures.TestCommon):
             # The sequence of box IDs should be the same as before, but with an
             # xml box at the end.
             box_ids = [box.box_id for box in jp2.box]
-            expected = ['jP  ', 'ftyp', 'jp2h', 'uuid', 'jp2c', 'xml ']
+            expected = ['jP  ', 'ftyp', 'jp2h', 'jp2c', 'xml ']
             self.assertEqual(box_ids, expected)
             self.assertEqual(
                 ET.tostring(jp2.box[-1].xml.getroot()),
@@ -770,7 +777,7 @@ class TestWrap(fixtures.TestCommon):
             with open(self.jp2file, 'rb') as ifile:
                 tfile.write(ifile.read())
             # Rewrite with codestream length as zero.
-            tfile.seek(3223)
+            tfile.seek(77)
             tfile.write(struct.pack('>I', 0))
             tfile.flush()
 
@@ -785,11 +792,11 @@ class TestWrap(fixtures.TestCommon):
         """Wrap jp2 with jp2c box length is 1, implies Q field"""
         with open(self.temp_jp2_filename, mode='wb') as tfile:
             with open(self.jp2file, 'rb') as ifile:
-                tfile.write(ifile.read(3223))
+                tfile.write(ifile.read(77))
                 # Write new L, T, Q fields
                 tfile.write(struct.pack('>I4sQ', 1, b'jp2c', 1132296 + 8))
                 # skip over the old L, T fields
-                ifile.seek(3231)
+                ifile.seek(85)
                 tfile.write(ifile.read())
             tfile.flush()
             jp2 = Jp2k(tfile.name)
@@ -1043,11 +1050,40 @@ class TestJp2Boxes(fixtures.TestCommon):
         box._filename = str(self.jp2file)
         box.codestream
 
+    def test_no_jp2h_box(self):
+        """
+        SCENARIO:  The JP2/JP2H box is missing
+
+        EXPECTED RESULT:  InvalidJp2kError
+        """
+        # Write a new JP2 file that omits the IHDR box.
+        j = Jp2k(self.jp2file)
+        jp2h = [box for box in j.box if box.box_id == 'jp2h'][0]
+        with open(self.temp_jp2_filename, mode='wb') as tfile:
+            numbytes = jp2h.offset
+            with open(self.jp2file, 'rb') as ifile:
+                # Write all the way up to the ihdr box
+                tfile.write(ifile.read(numbytes))
+
+                # Seek past the ihdr box
+                ifile.seek(jp2h.length, os.SEEK_CUR)
+
+                # Write the rest of the JP2 file
+                tfile.write(ifile.read(numbytes))
+
+            tfile.flush()
+
+            with self.assertRaises(InvalidJp2kError):
+                with warnings.catch_warnings():
+                    # Lots of things wrong with this file.
+                    warnings.simplefilter('ignore')
+                    Jp2k(tfile.name)
+
     def test_no_ihdr_box(self):
         """
         SCENARIO:  The JP2/IHDR box cannot be parsed.
 
-        EXPECTED RESULT:  An RuntimeError is issued.
+        EXPECTED RESULT:  InvalidJp2kError
         """
         # Write a new JP2 file that omits the IHDR box.
         j = Jp2k(self.jp2file)
@@ -1077,19 +1113,16 @@ class TestJp2Boxes(fixtures.TestCommon):
         """
         SCENARIO:  The JP2 file has no JP2C box.
 
-        EXPECTED RESULT:  An InvalidJp2kError is issued.
+        EXPECTED RESULT:  An InvalidJp2kError is issued when the file is
+        parsed.
         """
-        # Write a new JP2 file that omits the JP2C box.
-        j = Jp2k(self.jp2file)
-        jp2c = [box for box in j.box if box.box_id == 'jp2c'][0]
-        with open(self.temp_jp2_filename, mode='wb') as tfile:
-            numbytes = jp2c.offset
-            with open(self.jp2file, 'rb') as ifile:
-                tfile.write(ifile.read(numbytes))
-            tfile.flush()
+        testfile = ir.files('tests.data').joinpath('no_jp2c.jp2')
 
+        with warnings.catch_warnings():
+            # Lots of things wrong with this file.
+            warnings.simplefilter('ignore')
             with self.assertRaises(InvalidJp2kError):
-                Jp2k(tfile.name)
+                Jp2k(testfile)
 
     def test_two_jp2c_boxes(self):
         """
@@ -1489,18 +1522,27 @@ class TestRepr(fixtures.TestCommon):
         regex = re.compile(pattern, re.VERBOSE)
         self.assertRegex(repr(box), regex)
 
-    def test_uuid_box_xmp(self):
-        """Verify uuid repr method for XMP UUID box."""
-        jp2file = glymur.data.nemo()
-        j = Jp2k(jp2file)
-        box = j.box[3]
+    def test_xmp_uuid_box_repr(self):
+        """
+        Scenario:  Run an XMP UUID box thru repr.
+
+        Expected Result:  validated against a regex.
+
+        """
+        the_uuid = UUID('be7acfcb-97a9-42e8-9c71-999491e3afac')
+        raw_data = (
+            ir.files('tests.data')
+              .joinpath('simple_rdf.txt')
+              .read_text()
+              .encode('utf-8')
+        )
+
+        box = glymur.jp2box.UUIDBox(the_uuid=the_uuid, raw_data=raw_data)
 
-        # Since the raw_data parameter is a sequence of bytes which could be
-        # quite long, don't bother trying to make it conform to eval(repr()).
         pattern = r"""
             glymur.jp2box.UUIDBox\(
                 UUID\('be7acfcb-97a9-42e8-9c71-999491e3afac'\),\s
-                raw_data=<byte\sarray\s3122\selements>
+                raw_data=<byte\sarray\s410\selements>
             \)
         """
         regex = re.compile(pattern, re.VERBOSE)
