@@ -115,6 +115,28 @@ class TestSuite(fixtures.TestCommon):
         self.assertEqual(j.box[2].box[2].box[1].vertical_resolution, vresd)
         self.assertEqual(j.box[2].box[2].box[1].horizontal_resolution, hresd)
 
+    @unittest.skipIf(
+        not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
+    )
+    def test_capture_resolution_camera(self):
+        """
+        SCENARIO:  The capture_resolution keyword is specified.
+
+        EXPECTED RESULT:  The offset and length of the resolution superbox
+        are verified.
+        """
+        vresc, hresc = 0.1, 0.2
+        vresd, hresd = 0.3, 0.4
+        j = glymur.Jp2k(
+            self.temp_jp2_filename, data=fixtures.skimage.data.camera(),
+            capture_resolution=[vresc, hresc],
+            display_resolution=[vresd, hresd],
+        )
+
+        self.assertEqual(j.box[2].box[2].box_id, 'res ')
+        self.assertEqual(j.box[2].box[2].length, 44)
+        self.assertEqual(j.box[2].box[2].offset, 77)
+
     def test_capture_resolution_when_j2k_specified(self):
         """
         Scenario:  Capture/Display resolution boxes are specified when the file
@@ -132,24 +154,40 @@ class TestSuite(fixtures.TestCommon):
                 display_resolution=[vresd, hresd],
             )
 
-    def test_capture_resolution_when_not_writing(self):
+    def test_capture_resolution_when_writing_via_slicing(self):
         """
-        Scenario:  Jp2k is invoked in a read-only situation but capture/display
-        resolution arguments are supplied.
+        Scenario:  Jp2k is invoked in a write-by-slice situation and
+        capture/display resolution arguments are supplied.
 
-        Expected result:  RuntimeError
+        Expected result:  The resolution boxes are verified.
         """
         vresc, hresc = 0.1, 0.2
         vresd, hresd = 0.3, 0.4
 
         shutil.copyfile(self.jp2file, self.temp_jp2_filename)
 
-        with self.assertRaises(RuntimeError):
-            glymur.Jp2k(
-                self.temp_jp2_filename,
-                capture_resolution=[vresc, hresc],
-                display_resolution=[vresd, hresd],
-            )
+        j = glymur.Jp2k(
+            self.temp_jp2_filename,
+            capture_resolution=[vresc, hresc],
+            display_resolution=[vresd, hresd],
+        )
+
+        expected = self.jp2_data
+        j[:] = expected
+
+        actual = j[:]
+
+        np.testing.assert_array_equal(actual, expected)
+
+        self.assertEqual(j.box[2].box[2].box_id, 'res ')
+
+        self.assertEqual(j.box[2].box[2].box[0].box_id, 'resc')
+        self.assertEqual(j.box[2].box[2].box[0].vertical_resolution, vresc)
+        self.assertEqual(j.box[2].box[2].box[0].horizontal_resolution, hresc)
+
+        self.assertEqual(j.box[2].box[2].box[1].box_id, 'resd')
+        self.assertEqual(j.box[2].box[2].box[1].vertical_resolution, vresd)
+        self.assertEqual(j.box[2].box[2].box[1].horizontal_resolution, hresd)
 
     def test_capture_resolution_supplied_but_not_display(self):
         """
@@ -443,6 +481,47 @@ class TestSuite(fixtures.TestCommon):
         # PSNR should increase for the remaining images.
         self.assertTrue(np.all(np.diff(psnr[1:])) > 0)
 
+    @unittest.skipIf(
+        not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
+    )
+    def test_psnr_from_doctest(self):
+        """
+        SCENARIO:  Four peak signal-to-noise ratio values are supplied, the
+        last is zero.
+
+        EXPECTED RESULT:  Four quality layers, the first should be lossless.
+        """
+        kwargs = {
+            'data': fixtures.skimage.data.camera(),
+            'psnr': [30, 40, 50, 0],
+        }
+        j = Jp2k(self.temp_jp2_filename, **kwargs)
+
+        d = {}
+        for layer in range(4):
+            j.layer = layer
+            d[layer] = j[:]
+
+        with warnings.catch_warnings():
+            # MSE is zero for that first image, resulting in a divide-by-zero
+            # warning
+            warnings.simplefilter('ignore')
+            psnr = [
+                fixtures.skimage.metrics.peak_signal_noise_ratio(
+                    fixtures.skimage.data.camera(), d[j]
+                )
+                for j in range(4)
+            ]
+
+        # That first image should be lossless.
+        self.assertTrue(np.isinf(psnr[0]))
+
+        # None of the subsequent images should have inf PSNR.
+        self.assertTrue(not np.any(np.isinf(psnr[1:])))
+
+        # PSNR should increase for the remaining images.
+        self.assertTrue(np.all(np.diff(psnr[1:])) > 0)
+
     def test_NR_ENC_Bretagne1_ppm_2_encode(self):
         """
         SCENARIO:  Three peak signal-to-noise ratio values, two resolutions are
@@ -473,8 +552,9 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((32768, 32768)))
+        np.testing.assert_array_equal(
+            codestream.segment[2].precinct_size, np.array(((32768, 32768)))
+        )
 
     def test_NR_ENC_Bretagne1_ppm_1_encode(self):
         """
@@ -501,7 +581,9 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(c.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(c.segment[2].precinct_size, ((32768, 32768)))
+        np.testing.assert_array_equal(
+            c.segment[2].precinct_size, np.array((32768, 32768))
+        )
 
     def test_NR_ENC_Bretagne1_ppm_3_encode(self):
         """
@@ -535,9 +617,9 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(
+        np.testing.assert_array_equal(
             codestream.segment[2].precinct_size,
-            ((2, 2), (4, 4), (8, 8), (16, 16), (32, 32), (64, 64))
+            np.array(((2, 2), (4, 4), (8, 8), (16, 16), (32, 32), (64, 64)))
         )
 
     def test_NR_ENC_Bretagne2_ppm_4_encode(self):
@@ -583,12 +665,12 @@ class TestSuite(fixtures.TestCommon):
             codestream.segment[2].xform,
             glymur.core.WAVELET_XFORM_5X3_REVERSIBLE
         )
-        self.assertEqual(
+        np.testing.assert_array_equal(
             codestream.segment[2].precinct_size,
-            (
+            np.array((
                 (16, 16), (32, 32), (64, 64), (128, 128), (128, 128),
                 (128, 128)
-            )
+            ))
         )
 
     def test_NR_ENC_Bretagne2_ppm_5_encode(self):
@@ -623,8 +705,10 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((32768, 32768)))
+        np.testing.assert_array_equal(
+            codestream.segment[2].precinct_size,
+            np.array(((32768, 32768)))
+        )
 
     def test_sop_explicitly_true(self):
         """
@@ -702,8 +786,10 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((32768, 32768)))
+        np.testing.assert_array_equal(
+            codestream.segment[2].precinct_size,
+            np.array(((32768, 32768)))
+        )
 
         # 18 SOP segments.
         nsops = [x.nsop for x in codestream.segment
@@ -788,8 +874,10 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((32768, 32768)))
+        np.testing.assert_array_equal(
+            codestream.segment[2].precinct_size,
+            np.array(((32768, 32768)))
+        )
 
         # 18 EPH segments.
         ephs = [x for x in codestream.segment if x.marker_id == 'EPH']
@@ -861,8 +949,10 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((32768, 32768)))
+        np.testing.assert_array_equal(
+            codestream.segment[2].precinct_size,
+            np.array(((32768, 32768)))
+        )
 
     def test_NR_ENC_Cevennes1_bmp_9_encode(self):
         """
@@ -891,8 +981,10 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((32768, 32768)))
+        np.testing.assert_array_equal(
+            codestream.segment[2].precinct_size,
+            np.array(((32768, 32768)))
+        )
 
     def test_NR_ENC_Cevennes2_ppm_10_encode(self):
         """
@@ -921,8 +1013,10 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((32768, 32768)))
+        np.testing.assert_array_equal(
+            codestream.segment[2].precinct_size,
+            np.array(((32768, 32768)))
+        )
 
     def test_NR_ENC_Rome_bmp_11_encode(self):
         """
@@ -1000,8 +1094,10 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((32768, 32768)))
+        np.testing.assert_array_equal(
+            codestream.segment[2].precinct_size,
+            np.array(((32768, 32768)))
+        )
 
     def test_NR_ENC_random_issue_0005_tif_12_encode(self):
         """
@@ -1043,8 +1139,9 @@ class TestSuite(fixtures.TestCommon):
         )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((32768, 32768)))
+        np.testing.assert_array_equal(
+            codestream.segment[2].precinct_size, np.array((32768, 32768))
+        )
 
     def test_NR_ENC_issue141_rawl_23_encode(self):
         """
@@ -1071,10 +1168,9 @@ class TestSuite(fixtures.TestCommon):
         input/nonregression/X_5_2K_24_235_CBR_STEM24_000.tif
         """
         data = np.zeros((857, 2048, 3), dtype=np.uint8)
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=data,
-                     cinema2k=48, cratios=(200, 100, 50))
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=data,
+                 cinema2k=48, cratios=(200, 100, 50))
 
     def test_cinema4K_with_others(self):
         """
@@ -1083,35 +1179,33 @@ class TestSuite(fixtures.TestCommon):
         Original test file was input/nonregression/ElephantDream_4K.tif
         """
         data = np.zeros((4096, 2160, 3), dtype=np.uint8)
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=data,
-                     cinema4k=True, cratios=(200, 100, 50))
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=data,
+                 cinema4k=True, cratios=(200, 100, 50))
 
     def test_cblk_size_precinct_size(self):
         """
         code block sizes should never exceed half that of precinct size.
         """
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=self.j2k_data,
-                     cbsize=(64, 64), psizes=[(64, 64)])
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=self.j2k_data,
+                 cbsize=(64, 64), psizes=[(64, 64)])
 
     def test_cblk_size_not_power_of_two(self):
         """
         code block sizes should be powers of two.
         """
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=self.j2k_data, cbsize=(13, 12))
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=self.j2k_data, cbsize=(13, 12))
 
     def test_precinct_size_not_p2(self):
         """
         precinct sizes should be powers of two.
         """
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=self.j2k_data, psizes=[(173, 173)])
+        with self.assertRaises(RuntimeError):
+            Jp2k(
+                self.temp_j2k_filename, data=self.j2k_data, psizes=[(173, 173)]
+            )
 
     def test_code_block_dimensions(self):
         """
@@ -1120,25 +1214,25 @@ class TestSuite(fixtures.TestCommon):
         # opj_compress doesn't allow the dimensions of a codeblock
         # to be too small or too big, so neither will we.
         data = self.j2k_data
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            # opj_compress doesn't allow code block area to exceed 4096.
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=data, cbsize=(256, 256))
 
-            # opj_compress doesn't allow either dimension to be less than 4.
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=data, cbsize=(2048, 2))
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=data, cbsize=(2, 2048))
+        # opj_compress doesn't allow code block area to exceed 4096.
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=data, cbsize=(256, 256))
+
+        # opj_compress doesn't allow either dimension to be less than 4.
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=data, cbsize=(2048, 2))
+
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=data, cbsize=(2, 2048))
 
     def test_psnr_with_cratios(self):
         """
         Using psnr with cratios options is not allowed.
         """
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=self.j2k_data, psnr=[30, 35, 40],
-                     cratios=(2, 3, 4))
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=self.j2k_data, psnr=[30, 35, 40],
+                 cratios=(2, 3, 4))
 
     def test_irreversible(self):
         """
@@ -1203,16 +1297,14 @@ class TestSuite(fixtures.TestCommon):
     def test_unsupported_int32(self):
         """Should raise a runtime error if trying to write int32"""
         data = np.zeros((128, 128), dtype=np.int32)
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=data)
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=data)
 
     def test_unsupported_uint32(self):
         """Should raise a runtime error if trying to write uint32"""
         data = np.zeros((128, 128), dtype=np.uint32)
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=data)
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename, data=data)
 
     def test_write_with_version_too_early(self):
         """Should raise a runtime error if trying to write with version 1.3"""
@@ -1223,9 +1315,8 @@ class TestSuite(fixtures.TestCommon):
         ]
         for version in versions:
             with patch('glymur.version.openjpeg_version', new=version):
-                with open(self.temp_j2k_filename, mode='wb') as tfile:
-                    with self.assertRaises(RuntimeError):
-                        Jp2k(tfile.name, data=data)
+                with self.assertRaises(RuntimeError):
+                    Jp2k(self.temp_j2k_filename, data=data)
 
     def test_cblkh_different_than_width(self):
         """Verify that we can set a code block size where height does not equal
@@ -1241,10 +1332,9 @@ class TestSuite(fixtures.TestCommon):
 
     def test_too_many_dimensions(self):
         """OpenJP2 only allows 2D or 3D images."""
-        with open(self.temp_j2k_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name,
-                     data=np.zeros((128, 128, 2, 2), dtype=np.uint8))
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_j2k_filename,
+                 data=np.zeros((128, 128, 2, 2), dtype=np.uint8))
 
     def test_2d_rgb(self):
         """RGB must have at least 3 components."""
@@ -1305,9 +1395,8 @@ class TestSuite(fixtures.TestCommon):
     def test_specify_ycc(self):
         """Should reject YCC"""
         data = np.zeros((128, 128, 3), dtype=np.uint8)
-        with open(self.temp_jp2_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=data, colorspace='ycc')
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_jp2_filename, data=data, colorspace='ycc')
 
     def test_write_with_jp2_in_caps(self):
         """should be able to write with JP2 suffix."""
@@ -1360,9 +1449,8 @@ class TestSuite(fixtures.TestCommon):
         """
         j2k = Jp2k(self.j2kfile)
         expdata = j2k[:]
-        with open(self.temp_jp2_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=expdata[:, :, 0], mct=True)
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_jp2_filename, data=expdata[:, :, 0], mct=True)
 
     def test_write_grayscale_with_mct_set_to_none(self):
         """
@@ -1428,9 +1516,8 @@ class TestSuite(fixtures.TestCommon):
     def test_unrecognized_jp2_clrspace(self):
         """We only allow RGB and GRAYSCALE.  Should error out with others"""
         data = np.zeros((128, 128, 3), dtype=np.uint8)
-        with open(self.temp_jp2_filename, mode='wb') as tfile:
-            with self.assertRaises(RuntimeError):
-                Jp2k(tfile.name, data=data, colorspace='cmyk')
+        with self.assertRaises(RuntimeError):
+            Jp2k(self.temp_jp2_filename, data=data, colorspace='cmyk')
 
     def test_asoc_label_box(self):
         """Test asoc and label box"""
@@ -1527,9 +1614,11 @@ class TestSuite(fixtures.TestCommon):
         with open(self.jp2file, 'rb') as fptr:
             data = fptr.read()
             with open(self.temp_jp2_filename, mode='wb') as tfile:
-                # Codestream starts at byte 3323. SIZ marker at 3233.
+                # Codestream starts at byte 3223. SIZ marker at 3233.
                 # COD marker at 3282.  Subsampling at 3276.
-                offset = 3223
+                # Codestream starts at byte 77. SIZ marker at 10.
+                # COD marker at 59.  Subsampling at 53.
+                offset = 77
                 tfile.write(data[0:offset + 52])
 
                 # Make the DY bytes of the SIZ segment zero.  That means that
@@ -1753,7 +1842,7 @@ class TestSuite(fixtures.TestCommon):
 
     def test_1x1_tile(self):
         """
-        SCENARIO:  Write an image that is tiled 1x1.
+        SCENARIO:  Write by tiles an image that is tiled 1x1.
 
         EXPECTED RESULT:  RuntimeError, as this triggers an unresolved
         bug, issue586.
@@ -1769,5 +1858,26 @@ class TestSuite(fixtures.TestCommon):
             self.temp_j2k_filename, shape=shape, tilesize=tilesize,
         )
         with self.assertRaises(RuntimeError):
-            for tw in j.get_tilewriters():
-                tw[:] = j2k_data
+            j.get_tilewriters()
+
+    def test_openjpeg_library_too_old_for_tile_writing(self):
+        """
+        SCENARIO:  Try to create a jp2 file via writing tiles, but the openjpeg
+        library is too old.
+
+        EXPECTED RESULT:  RuntimeError.
+        """
+        j2k_data = fixtures.skimage.data.astronaut()
+
+        shape = (
+            j2k_data.shape[0] * 2, j2k_data.shape[1] * 2, j2k_data.shape[2]
+        )
+        tilesize = (j2k_data.shape[0], j2k_data.shape[1])
+
+        j = Jp2k(
+            self.temp_j2k_filename, shape=shape, tilesize=tilesize,
+        )
+        with patch('glymur.version.openjpeg_version', new='2.2.0'):
+            with self.assertRaises(RuntimeError):
+                for tw in j.get_tilewriters():
+                    tw[:] = j2k_data
