@@ -23,35 +23,26 @@ from . import fixtures
 from .fixtures import OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG
 
 
-def _file_helper(filename, module='tests.data.skimage'):
-    """
-    Mask importlib.resources differences between >=3.9 and below.
-    """
-    if sys.version_info[1] >= 9:
-        return ir.files(module).joinpath(filename)
-    else:
-        with ir.path(module, filename) as path:
-            return path
-
-
 @unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
 class TestSuite(fixtures.TestCommon):
 
     @classmethod
     def setUpClass(cls):
 
-        cls.astronaut8 = _file_helper('astronaut8.tif')
-        cls.astronaut_u16 = _file_helper('astronaut_uint16.tif')
-        cls.astronaut_s_u16 = _file_helper('astronaut_s_uint16.tif')
-        cls.astronaut8_stripped = _file_helper('astronaut8_stripped.tif')
-        cls.astronaut_ycbcr_jpeg_tiled = _file_helper('astronaut_ycbcr_jpeg_tiled.tif')  # noqa : E501
-        cls.moon = _file_helper('moon.tif')
-        cls.moon_3x3 = _file_helper('moon_3x3.tif')
-        cls.moon_3stripped = _file_helper('moon3_stripped.tif')
-        cls.moon3_partial_last_strip = _file_helper('moon3_partial_last_strip.tif')  # noqa : E501
-        cls.ycbcr_bg = _file_helper('ycbcr_bg.tif')
-        cls.ycbcr_stripped = _file_helper('ycbcr_stripped.tif')
-        cls.stripped = _file_helper('stripped.tif')
+        root = ir.files('tests.data.skimage')
+
+        cls.astronaut8 = root.joinpath('astronaut8.tif')
+        cls.astronaut_u16 = root.joinpath('astronaut_uint16.tif')
+        cls.astronaut_s_u16 = root.joinpath('astronaut_s_uint16.tif')
+        cls.astronaut8_stripped = root.joinpath('astronaut8_stripped.tif')
+        cls.astronaut_ycbcr_jpeg_tiled = root.joinpath('astronaut_ycbcr_jpeg_tiled.tif')  # noqa : E501
+        cls.moon = root.joinpath('moon.tif')
+        cls.moon_3x3 = root.joinpath('moon_3x3.tif')
+        cls.moon_3stripped = root.joinpath('moon3_stripped.tif')
+        cls.moon3_partial_last_strip = root.joinpath('moon3_partial_last_strip.tif')  # noqa : E501
+        cls.ycbcr_bg = root.joinpath('ycbcr_bg.tif')
+        cls.ycbcr_stripped = root.joinpath('ycbcr_stripped.tif')
+        cls.stripped = root.joinpath('stripped.tif')
 
         test_tiff_dir = tempfile.mkdtemp()
         cls.test_tiff_path = pathlib.Path(test_tiff_dir)
@@ -653,15 +644,15 @@ class TestSuite(fixtures.TestCommon):
 
     def test_partial_last_strip(self):
         """
-        SCENARIO:  Convert monochromatic TIFF file to JP2.  The TIFF has a
-        partial last strip.
+        SCENARIO:  Convert monochromatic stripped TIFF with a partial last
+        strip to a single-tile JP2.
 
-        EXPECTED RESULT:  The data matches.  The JP2 file has 4 tiles.
+        EXPECTED RESULT:  The data matches.  The JP2 file has 1 tile.
         """
         with Tiff2Jp2k(
             self.moon3_partial_last_strip,
             self.temp_jp2_filename,
-            tilesize=(48, 48), verbose='DEBUG'
+            verbose='DEBUG'
         ) as j:
             j.run()
 
@@ -676,8 +667,8 @@ class TestSuite(fixtures.TestCommon):
         c = jp2.get_codestream()
         self.assertEqual(c.segment[1].xsiz, 90)
         self.assertEqual(c.segment[1].ysiz, 90)
-        self.assertEqual(c.segment[1].xtsiz, 48)
-        self.assertEqual(c.segment[1].ytsiz, 48)
+        self.assertEqual(c.segment[1].xtsiz, 90)
+        self.assertEqual(c.segment[1].ytsiz, 90)
 
     def test_32bit(self):
         """
@@ -685,7 +676,7 @@ class TestSuite(fixtures.TestCommon):
 
         EXPECTED RESULT:  RuntimeError
         """
-        infile = _file_helper('uint32.tif', module='tests.data.tiff')
+        infile = ir.files('tests.data.tiff').joinpath('uint32.tif')
         with Tiff2Jp2k(infile, self.temp_jp2_filename) as j:
             with self.assertRaises(RuntimeError):
                 j.run()
@@ -696,7 +687,7 @@ class TestSuite(fixtures.TestCommon):
 
         EXPECTED RESULT:  RuntimeError
         """
-        infile = _file_helper('ieeefp32.tif', module='tests.data.tiff')
+        infile = ir.files('tests.data.tiff').joinpath('ieeefp32.tif')
         with Tiff2Jp2k(infile, self.temp_jp2_filename) as j:
             with self.assertRaises(RuntimeError):
                 j.run()
@@ -1068,7 +1059,7 @@ class TestSuite(fixtures.TestCommon):
 
         Expected result:  RuntimeError
         """
-        infile = _file_helper('cmyk.tif', module='tests.data.tiff')
+        infile = ir.files('tests.data.tiff').joinpath('cmyk.tif')
         with Tiff2Jp2k(infile, self.temp_jp2_filename) as j:
             with self.assertRaises(RuntimeError):
                 j.run()
@@ -1632,20 +1623,17 @@ class TestSuite(fixtures.TestCommon):
             with Tiff2Jp2k(path, self.temp_jp2_filename):
                 pass
 
-    def test_colormap(self):
+    def test_tiff_with_colormap__exclude_colormap(self):
         """
-        Scenario:  The input "TIFF" has a colormap tag.
+        Scenario:  The input "TIFF" has a colormap tag.  Write the UUID box
+        without the ColorMap tag.
 
         Expected Result:  The output JP2 has a single layer and the jp2h box
-        has a pclr box.
+        has a pclr box.   The colormap tag is verified not to exist in the UUID
+        box.
         """
-        for tag in ['ColorMap', 'StripOffsets']:
-            with self.subTest(tag=tag):
-                self._test_colormap(tag=tag)
 
-    def _test_colormap(self, tag):
-
-        kwargs = {'tilesize': (32, 32), 'exclude_tags': [tag]}
+        kwargs = {'tilesize': (32, 32), 'exclude_tags': ['ColorMap']}
         path = ir.files('tests.data').joinpath('issue572.tif')
         with Tiff2Jp2k(path, self.temp_jp2_filename, **kwargs) as p:
             p.run()
@@ -1674,14 +1662,61 @@ class TestSuite(fixtures.TestCommon):
 
         # The last box should be the exif uuid.  It may or may not have the
         # colormap tag depending on what was specified.
+        self.assertEqual(j.box[-1].box_id, 'uuid')
         exif_box = j.box[-1]
         actual = exif_box.uuid
         expected = UUID(bytes=b'JpgTiffExif->JP2')
         self.assertEqual(actual, expected)
-        if tag == 'ColorMap':
-            self.assertNotIn('ColorMap', exif_box.data)
-        else:
-            self.assertIn('ColorMap', exif_box.data)
+
+        self.assertNotIn('ColorMap', exif_box.data)
+        self.assertIn('StripOffsets', exif_box.data)
+
+    def test_tiff_with_colormap__exclude_stripoffsets(self):
+        """
+        Scenario:  The input "TIFF" has a colormap tag.  Write the UUID box
+        without the StripOffsets tag.
+
+        Expected Result:  The output JP2 has a single layer and the jp2h box
+        has a pclr box.   The stripoffsets tag is verified not to exist in the
+        UUID box.
+        """
+        kwargs = {'tilesize': (32, 32), 'exclude_tags': ['StripOffsets']}
+        path = ir.files('tests.data').joinpath('issue572.tif')
+        with Tiff2Jp2k(path, self.temp_jp2_filename, **kwargs) as p:
+            p.run()
+
+        j = Jp2k(self.temp_jp2_filename)
+
+        # the image header box shows just a single layer
+        shape = (
+            j.box[2].box[0].height,
+            j.box[2].box[0].width,
+            j.box[2].box[0].num_components,
+        )
+        self.assertEqual(shape, (64, 64, 1))
+
+        # the colr box says sRGB, not greyscale
+        self.assertEqual(j.box[2].box[1].colorspace, SRGB)
+
+        # a pclr box exists
+        self.assertEqual(j.box[2].box[2].box_id, 'pclr')
+
+        # a component mapping box exists
+        self.assertEqual(j.box[2].box[3].box_id, 'cmap')
+        self.assertEqual(j.box[2].box[3].component_index, (0, 0, 0))
+        self.assertEqual(j.box[2].box[3].mapping_type, (1, 1, 1))
+        self.assertEqual(j.box[2].box[3].palette_index, (0, 1, 2))
+
+        # The last box should be the exif uuid.  It may or may not have the
+        # colormap tag depending on what was specified.
+        self.assertEqual(j.box[-1].box_id, 'uuid')
+        exif_box = j.box[-1]
+        actual = exif_box.uuid
+        expected = UUID(bytes=b'JpgTiffExif->JP2')
+        self.assertEqual(actual, expected)
+
+        self.assertIn('ColorMap', exif_box.data)
+        self.assertNotIn('StripOffsets', exif_box.data)
 
     def test_excluded_tags_is_none(self):
         """
